import freetype
from freetype.raw import FT_Get_TrueType_Engine_Type
from enum import Enum

class truetype_engine_type(Enum):
    NONE = 0
    UNPATENTED = 1
    PATENTED = 2

def get_truetype_engine_type():
    value = int(FT_Get_TrueType_Engine_Type(freetype._handle))
    if 0 <= value <= 2:
        return truetype_engine_type(value)



__all__ = [
    "truetype_engine_type",
    "get_truetype_engine_type",
    "load_sfnt_table",
    "open_face",
]
from .get_truetype_engine_type import (
    truetype_engine_type, get_truetype_engine_type
)
from .load_sfnt_table import load_sfnt_table
from .open_face import open_face



import freetype
from freetype.raw import FT_Load_Sfnt_Table
import ctypes
from struct import unpack_from

def load_sfnt_table(face: freetype.Face, tag: str):
    try:
        face_ref = face._FT_Face
        tag_u32 = ctypes.c_uint32(unpack_from(">L", tag.encode("U8"), 0)[0])
        len_i32 = ctypes.c_int32(0)
        FT_Load_Sfnt_Table(face_ref, tag_u32, 0, None, ctypes.byref(len_i32))
        if len_i32.value:
            buf_u8n = ctypes.create_string_buffer(len_i32.value)
            FT_Load_Sfnt_Table(face_ref, tag_u32, 0, buf_u8n, ctypes.byref(len_i32))
            return buf_u8n.raw
    except Exception as e:
        print(e)



import freetype
import pathlib
import platform
import io

def open_face(path: pathlib.Path, index=0):
    if path.exists():
        if platform.system() in ["Linux", "Darwin"]:
            return freetype.Face(path.as_posix(), index=index)
        else:
            data = io.BytesIO(path.read_bytes())
            return freetype.Face(data, index=index)
